@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -19,21 +19,21 @@ use namespace::clean;
 
 has intervals => (
     is  => 'ro',
-    isa => sub { die 'not an array reference' unless ref $_[0] eq 'ARRAY' },
+    isa => sub { croak 'not an array reference' unless ref $_[0] eq 'ARRAY' },
     default => sub { [qw(-3 -2 -1 1 2 3)] },
 );
 
 
 has octave => (
     is  => 'ro',
-    isa => sub { die 'not a positive integer' unless $_[0] =~ /^\d+$/ },
+    isa => sub { croak 'not a positive integer' unless $_[0] =~ /^\d+$/ },
     default => sub { 2 },
 );
 
 
 has verbose => (
     is  => 'ro',
-    isa => sub { die 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    isa => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
     default => sub { 0 },
 );
 
@@ -134,7 +134,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -151,12 +151,16 @@ version 0.0103
 
 C<MIDI::Bassline::Walk> generates randomized, walking basslines.
 
-The logic (and music theory) implemented here, can generate some sour
-notes.  And sometimes too much!  This is an approximate composition
-tool, and not a drop-in bass player.  Import the rendered MIDI into a
-DAW and alter things until they are suitable.
+The "formula" implemented by this module is basically, "play any notes
+of the chord-root scale, plus the notes of the chord that may differ,
+minus the notes those replaced."
 
-The chords recognized by this module, are those known by
+The logic (and music theory) implemented here, can generate some sour
+notes.  This is an approximate composition tool, and not a drop-in
+bass player.  Import rendered MIDI into a DAW and alter things until
+they are suitable.
+
+The chords recognized by this module, are those known to
 L<Music::Chord::Note>.  Please see the source of that module for the
 list.
 
